# Name: LoggerScript.py
#
# Author: Winko Erades van den Berg
# Date: November 24, 2019
# Revised: 
#
# Purpose: Read sensors from Sense Hat and write them to log-file
#
# You might need to make this file executable by giving executable
# permissions: eg. chmod +x ./netbook.bash
#
# You can schedule this script on your Raspberry using crontab
#
# Usage:
# python ./LoggerScript.py

from sense_hat import SenseHat
from datetime import datetime
import socket

sense = SenseHat()

# Get the Pi Hostname
sock_name = socket.gethostname()

# Date and Time object containing current date and time
now = datetime.now()

# Convert the date and time to dd/mm/YY H:M:S
dt_string = now.strftime("%Y-%m-%d %H:%M:%S")

# Readings from three sensors
t = sense.get_temperature()
p = sense.get_pressure()
h = sense.get_humidity()

# Round the values to one decimal place
t = round(t, 1)
p = round(p, 1)
h = round(h, 1)

# Construct the message
message = sock_name + ";" + dt_string + ";" + str(t) + ";" + str(p) + ";" + str(h)  

# Append the message to the log file
f=open("Sensor_Log.txt","a+")
f.write(message)
f.write('\n')
f.close()

# For optical feedabck you might want to display a scrolling message
sense.show_message(message, scroll_speed=0.05)
